@@ -149,7 +149,7 @@ gnome_app_class_init (GnomeAppClass *class)
 				      g_param_spec_string ("app_id",
 							   _("App ID"),
 							   _("The application ID string"),
-							   program_invocation_short_name,
+							   g_get_prgname (),
 							   (G_PARAM_READABLE |
 							    G_PARAM_WRITABLE)));
 }
@@ -190,17 +190,12 @@ gnome_app_get_property (GObject       *object,
 static void
 gnome_app_instance_init (GnomeApp *app)
 {
-	const char *str = NULL;
-	GValue value = { 0, };
-
+	const char *icons;
+		
 	app->_priv = NULL;
 	/* XXX: when there is some private stuff enable this
 	app->_priv = g_new0(GnomeAppPrivate, 1);
 	*/
-
-	app->name = NULL;
-	app->prefix = NULL;
-
 	app->accel_group = gtk_accel_group_new ();
 	gtk_window_add_accel_group (GTK_WINDOW (app), app->accel_group);
 	
@@ -208,6 +203,8 @@ gnome_app_instance_init (GnomeApp *app)
 	gtk_container_add (GTK_CONTAINER (app), app->vbox);
 
 	app->dock = bonobo_dock_new ();
+	app->layout = bonobo_dock_layout_new ();
+
 	gtk_box_pack_start (GTK_BOX (app->vbox), app->dock,
 			    TRUE, TRUE, 0);
 
@@ -215,23 +212,19 @@ gnome_app_instance_init (GnomeApp *app)
 			    "layout_changed",
 			    GTK_SIGNAL_FUNC (layout_changed),
 			    (gpointer) app);
-
-	app->layout = g_object_ref (bonobo_dock_layout_new ());
-	gtk_object_sink (GTK_OBJECT (app->layout));
-
+	
 	app->enable_layout_config = TRUE;
 
-	g_value_init (&value, G_TYPE_STRING);
-	g_object_get_property (G_OBJECT (gnome_program_get ()),
-			       LIBGNOMEUI_PARAM_DEFAULT_ICON, &value);
-	str = g_value_get_string (&value);
-	if (str != NULL) {
-		char **files = g_strsplit (str, ";", -1);
+	g_object_get (G_OBJECT (gnome_program_get ()),
+		      LIBGNOMEUI_PARAM_DEFAULT_ICON, &icons,
+		      NULL);
+
+	if (icons && *icons) {
+		char **files = g_strsplit (icons, ";", -1);
 		gnome_window_icon_set_from_file_list (GTK_WINDOW (app),
 						      (const char **)files);
 		g_strfreev (files);
 	}
-	g_value_unset (&value);
 }
 
 static void
@@ -258,7 +251,7 @@ gnome_app_show (GtkWidget *widget)
 		if (app->enable_layout_config)
 			write_layout_config (app, app->layout);
 
-		gtk_object_unref (GTK_OBJECT (app->layout));
+		g_object_unref (G_OBJECT (app->layout));
 		app->layout = NULL;
 	}
 			
@@ -281,10 +274,9 @@ layout_changed (GtkWidget *w, gpointer data)
 	if (app->enable_layout_config) {
 		BonoboDockLayout *layout;
 
-		layout = g_object_ref (bonobo_dock_get_layout (BONOBO_DOCK (app->dock)));
-		gtk_object_sink (GTK_OBJECT (layout));
+		layout = bonobo_dock_get_layout (BONOBO_DOCK (app->dock));
 		write_layout_config (app, layout);
-		gtk_object_unref (GTK_OBJECT (layout));
+		g_object_unref (G_OBJECT (layout));
 	}
 }
 
@@ -362,7 +354,7 @@ gnome_app_destroy (GtkObject *object)
 	app = GNOME_APP (object);
 
 	if (app->accel_group != NULL) {
-		gtk_accel_group_unref (app->accel_group);
+		g_object_unref (G_OBJECT (app->accel_group));
 		app->accel_group = NULL;
 	}
 
@@ -474,7 +466,7 @@ gnome_app_set_menus (GnomeApp *app, GtkMenuBar *menubar)
 	behavior = (BONOBO_DOCK_ITEM_BEH_EXCLUSIVE
 		    | BONOBO_DOCK_ITEM_BEH_NEVER_VERTICAL);
 	
-	if ( ! gnome_gconf_get_bool ("/desktop/gnome/interface/menubar-detachable"))
+	if ( ! gnome_gconf_get_bool ("/desktop/gnome/interface/menubar_detachable"))
 		behavior |= BONOBO_DOCK_ITEM_BEH_LOCKED;
 
 	dock_item = bonobo_dock_item_new (GNOME_APP_MENUBAR_NAME,
@@ -482,27 +474,9 @@ gnome_app_set_menus (GnomeApp *app, GtkMenuBar *menubar)
 	gtk_container_add (GTK_CONTAINER (dock_item), GTK_WIDGET (menubar));
 
 	app->menubar = GTK_WIDGET (menubar);
-
-	/* To have menubar relief agree with the toolbar (and have the relief
-	 * outside of smaller handles), substitute the dock item's relief for
-	 * the menubar's relief, but don't change the size of the menubar in
-	 * the process. */
-#ifdef FIXME
-	gtk_menu_bar_set_shadow_type (GTK_MENU_BAR (app->menubar),
-				      GTK_SHADOW_NONE);
-#endif
-	if (gnome_gconf_get_bool ("/desktop/gnome/interface/menubar-relief")) {
-		guint border_width;
-		
-		gtk_container_set_border_width (GTK_CONTAINER (dock_item), 2);
-		border_width = GTK_CONTAINER (app->menubar)->border_width;
-		if (border_width >= 2)
-			border_width -= 2;
-		gtk_container_set_border_width (GTK_CONTAINER (app->menubar),
-						border_width);
-	} else
-		bonobo_dock_item_set_shadow_type (BONOBO_DOCK_ITEM (dock_item),
-						 GTK_SHADOW_NONE);
+	
+	bonobo_dock_item_set_shadow_type (BONOBO_DOCK_ITEM (dock_item),
+					  GTK_SHADOW_NONE);
 
 	if (app->layout != NULL)
 		bonobo_dock_layout_add_item (app->layout,
@@ -671,7 +645,7 @@ gnome_app_set_toolbar (GnomeApp *app,
 	   requirement.  We only do this for backwards compatibility.  */
 	behavior = BONOBO_DOCK_ITEM_BEH_EXCLUSIVE;
 	
-	if ( ! gnome_gconf_get_bool ("/desktop/gnome/interface/toolbar-detachable"))
+	if ( ! gnome_gconf_get_bool ("/desktop/gnome/interface/toolbar_detachable"))
 		behavior |= BONOBO_DOCK_ITEM_BEH_LOCKED;
 	
 	gnome_app_add_toolbar (app, toolbar,
